#
# spec file for package plexus-resources
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           plexus-resources
Version:        1.3.0
Release:        1.1
Summary:        Plexus Resource Manager
License:        MIT
Group:          Development/Libraries/Java
URL:            https://github.com/codehaus-plexus/plexus-resources
Source0:        %{name}-%{version}.tar.xz
Source1:        %{name}-build.xml
BuildRequires:  ant
BuildRequires:  atinject
BuildRequires:  fdupes
BuildRequires:  javapackages-local >= 6
BuildRequires:  plexus-utils
BuildRequires:  plexus-xml
BuildRequires:  sisu-inject
BuildRequires:  slf4j
BuildArch:      noarch

%description
Plexus contains end-to-end developer tools for writing applications.
At the core is the container, which can be embedded or for an
application server. There are many reusable components for hibernate,
form processing, jndi, i18n, velocity, etc. Plexus also includes an
application server which is like a J2EE application server.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Documentation/HTML

%description javadoc
API documentation for %{name}.

%prep
%setup -q
cp %{SOURCE1} build.xml

%build
mkdir -p lib
build-jar-repository -s lib atinject org.eclipse.sisu.inject plexus/utils plexus/xml slf4j/api
%{ant} jar javadoc

%install
# jar
install -dm 0755 %{buildroot}%{_javadir}/plexus
install -pm 0644 target/%{name}-%{version}.jar %{buildroot}%{_javadir}/plexus/resources.jar
# pom
install -dm 0755 %{buildroot}%{_mavenpomdir}/plexus
%{mvn_install_pom} pom.xml %{buildroot}%{_mavenpomdir}/plexus/resources.pom
%add_maven_depmap plexus/resources.pom plexus/resources.jar
# javadoc
install -dm 0755 %{buildroot}%{_javadocdir}/%{name}
cp -pr target/site/apidocs/* %{buildroot}%{_javadocdir}/%{name}/
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles

%files javadoc
%{_javadocdir}/%{name}

%changelog
* Tue Oct  8 2024 Fridrich Strba <fstrba@suse.com>
- Update to version 1.3
  * Changes:
  * Ignore mac os .DS_Store
  * Update codebase to current Java level
  * Restore public constructor to DefaultResourceManager
- Fetch sources using source service
* Sun May 26 2024 Fridrich Strba <fstrba@suse.com>
- Use the org.eclipse.sisu:org.eclipse.sisu.plexus artifact to avoid
  conflict/choise of providers
* Thu May 16 2024 Fridrich Strba <fstrba@suse.com>
- Use sisu-plexus instead of plexus-containers-container-default
- Clean up the spec file
* Sun Mar 20 2022 Fridrich Strba <fstrba@suse.com>
- Build with source and target levels 8
* Mon Apr  1 2019 Jan Engelhardt <jengelh@inai.de>
- Descript package, not the project vision.
* Thu Mar  7 2019 Fridrich Strba <fstrba@suse.com>
- Initial packaging of plexus-resource 1.0-alpha-7
- Generate and customize ant build file
  * generate the plexus components.xml descriptor using
    plexus-metadata-generator
